==> ejc-budgetmanage-impl-3.0.0-20220325.144208-24-sources.jar: com/ejianc/business/record/vo/RecordquotadesigndetaillVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 限额设计表变更记录子表
 * 
 * @author generator
 * 
 */
public class RecordquotadesigndetaillVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long recordMid; // 限额设计变更记录主表id
    private java.lang.String sort; // 序号
    private java.lang.String sonItemCode; // 子目编码
    private java.lang.String sonItemName; // 子目名称
    private java.lang.String sonItemDescribe; // 子目特征描述
    private java.math.BigDecimal engineering; // 工程量
    private java.math.BigDecimal labor; // 人工费
    private java.math.BigDecimal material; // 材料费
    private java.math.BigDecimal mechanical; // 机械费
    private java.math.BigDecimal management; // 企业管理费
    private java.math.BigDecimal profit; // 利润
    private java.math.BigDecimal unitPrice; // 综合单价
    private java.math.BigDecimal shutLabor; // 人工费
    private java.math.BigDecimal shutMaterial; // 材料费
    private java.math.BigDecimal shutMechanical; // 机械费
    private java.math.BigDecimal shutManagement; // 企业管理费
    private java.math.BigDecimal shutProfit; // 利润
    private java.math.BigDecimal shutPrice; // 合价(元)
    private java.math.BigDecimal clubInsurance; // 社保
    private java.math.BigDecimal housing; // 住房
    private java.math.BigDecimal reserved1; // 预留1
    private java.math.BigDecimal reserved2; // 预留2
    private java.math.BigDecimal reserved3; // 预留3
    private java.math.BigDecimal tax; // 税金
    private java.math.BigDecimal estimation; // 暂估价(元)
    private java.lang.String memo; // 备注
    

    /**
     * 限额设计变更记录主表id
     */
    public java.lang.Long getRecordMid() {
        return recordMid;
    }

    /**
     * 限额设计变更记录主表id
     */
    public void setRecordMid(java.lang.Long recordMid) {
        this.recordMid = recordMid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 子目编码
     */
    public java.lang.String getSonItemCode() {
        return sonItemCode;
    }

    /**
     * 子目编码
     */
    public void setSonItemCode(java.lang.String sonItemCode) {
        this.sonItemCode = sonItemCode;
    }
    /**
     * 子目名称
     */
    public java.lang.String getSonItemName() {
        return sonItemName;
    }

    /**
     * 子目名称
     */
    public void setSonItemName(java.lang.String sonItemName) {
        this.sonItemName = sonItemName;
    }
    /**
     * 子目特征描述
     */
    public java.lang.String getSonItemDescribe() {
        return sonItemDescribe;
    }

    /**
     * 子目特征描述
     */
    public void setSonItemDescribe(java.lang.String sonItemDescribe) {
        this.sonItemDescribe = sonItemDescribe;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getEngineering() {
        return engineering;
    }

    /**
     * 工程量
     */
    public void setEngineering(java.math.BigDecimal engineering) {
        this.engineering = engineering;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLabor() {
        return labor;
    }

    /**
     * 人工费
     */
    public void setLabor(java.math.BigDecimal labor) {
        this.labor = labor;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterial() {
        return material;
    }

    /**
     * 材料费
     */
    public void setMaterial(java.math.BigDecimal material) {
        this.material = material;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanical() {
        return mechanical;
    }

    /**
     * 机械费
     */
    public void setMechanical(java.math.BigDecimal mechanical) {
        this.mechanical = mechanical;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getManagement() {
        return management;
    }

    /**
     * 企业管理费
     */
    public void setManagement(java.math.BigDecimal management) {
        this.management = management;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfit() {
        return profit;
    }

    /**
     * 利润
     */
    public void setProfit(java.math.BigDecimal profit) {
        this.profit = profit;
    }
    /**
     * 综合单价
     */
    public java.math.BigDecimal getUnitPrice() {
        return unitPrice;
    }

    /**
     * 综合单价
     */
    public void setUnitPrice(java.math.BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getShutLabor() {
        return shutLabor;
    }

    /**
     * 人工费
     */
    public void setShutLabor(java.math.BigDecimal shutLabor) {
        this.shutLabor = shutLabor;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getShutMaterial() {
        return shutMaterial;
    }

    /**
     * 材料费
     */
    public void setShutMaterial(java.math.BigDecimal shutMaterial) {
        this.shutMaterial = shutMaterial;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getShutMechanical() {
        return shutMechanical;
    }

    /**
     * 机械费
     */
    public void setShutMechanical(java.math.BigDecimal shutMechanical) {
        this.shutMechanical = shutMechanical;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getShutManagement() {
        return shutManagement;
    }

    /**
     * 企业管理费
     */
    public void setShutManagement(java.math.BigDecimal shutManagement) {
        this.shutManagement = shutManagement;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getShutProfit() {
        return shutProfit;
    }

    /**
     * 利润
     */
    public void setShutProfit(java.math.BigDecimal shutProfit) {
        this.shutProfit = shutProfit;
    }
    /**
     * 合价(元)
     */
    public java.math.BigDecimal getShutPrice() {
        return shutPrice;
    }

    /**
     * 合价(元)
     */
    public void setShutPrice(java.math.BigDecimal shutPrice) {
        this.shutPrice = shutPrice;
    }
    /**
     * 社保
     */
    public java.math.BigDecimal getClubInsurance() {
        return clubInsurance;
    }

    /**
     * 社保
     */
    public void setClubInsurance(java.math.BigDecimal clubInsurance) {
        this.clubInsurance = clubInsurance;
    }
    /**
     * 住房
     */
    public java.math.BigDecimal getHousing() {
        return housing;
    }

    /**
     * 住房
     */
    public void setHousing(java.math.BigDecimal housing) {
        this.housing = housing;
    }
    /**
     * 预留1
     */
    public java.math.BigDecimal getReserved1() {
        return reserved1;
    }

    /**
     * 预留1
     */
    public void setReserved1(java.math.BigDecimal reserved1) {
        this.reserved1 = reserved1;
    }
    /**
     * 预留2
     */
    public java.math.BigDecimal getReserved2() {
        return reserved2;
    }

    /**
     * 预留2
     */
    public void setReserved2(java.math.BigDecimal reserved2) {
        this.reserved2 = reserved2;
    }
    /**
     * 预留3
     */
    public java.math.BigDecimal getReserved3() {
        return reserved3;
    }

    /**
     * 预留3
     */
    public void setReserved3(java.math.BigDecimal reserved3) {
        this.reserved3 = reserved3;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 暂估价(元)
     */
    public java.math.BigDecimal getEstimation() {
        return estimation;
    }

    /**
     * 暂估价(元)
     */
    public void setEstimation(java.math.BigDecimal estimation) {
        this.estimation = estimation;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/record/vo/RecordquotadesigndetaillVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.bedget.vo.QuotadesigndetailVO;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 限额设计表变更记录子表
 * 
 * @author generator
 * 
 */
public class RecordquotadesigndetaillVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long recordMid; // 限额设计变更记录主表id
    private java.lang.String sort; // 序号
    private java.lang.String sonItemCode; // 子目编码
    private java.lang.String sonItemName; // 子目名称
    private java.lang.String sonItemDescribe; // 子目特征描述
    private java.math.BigDecimal engineering; // 工程量
    private java.math.BigDecimal labor; // 人工费
    private java.math.BigDecimal material; // 材料费
    private java.math.BigDecimal mechanical; // 机械费
    private java.math.BigDecimal management; // 企业管理费
    private java.math.BigDecimal profit; // 利润
    private java.math.BigDecimal unitPrice; // 综合单价
    private java.math.BigDecimal shutLabor; // 人工费
    private java.math.BigDecimal shutMaterial; // 材料费
    private java.math.BigDecimal shutMechanical; // 机械费
    private java.math.BigDecimal shutManagement; // 企业管理费
    private java.math.BigDecimal shutProfit; // 利润
    private java.math.BigDecimal shutPrice; // 合价(元)
    private java.math.BigDecimal clubInsurance; // 社保
    private java.math.BigDecimal housing; // 住房
    private java.math.BigDecimal reserved1; // 预留1
    private java.math.BigDecimal reserved2; // 预留2
    private java.math.BigDecimal reserved3; // 预留3
    private java.math.BigDecimal tax; // 税金
    private java.math.BigDecimal estimation; // 暂估价(元)
    private java.lang.String memo; // 备注

    private java.lang.String tid;
    private java.lang.String tpid;

    private List<RecordquotadesigndetaillVO> children = new ArrayList<>();
    public List<RecordquotadesigndetaillVO> getChildren() {
        return children;
    }

    public void setChildren(List<RecordquotadesigndetaillVO> children) {
        this.children = children;
    }
    

    /**
     * 限额设计变更记录主表id
     */
    public java.lang.Long getRecordMid() {
        return recordMid;
    }

    /**
     * 限额设计变更记录主表id
     */
    public void setRecordMid(java.lang.Long recordMid) {
        this.recordMid = recordMid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 子目编码
     */
    public java.lang.String getSonItemCode() {
        return sonItemCode;
    }

    /**
     * 子目编码
     */
    public void setSonItemCode(java.lang.String sonItemCode) {
        this.sonItemCode = sonItemCode;
    }
    /**
     * 子目名称
     */
    public java.lang.String getSonItemName() {
        return sonItemName;
    }

    /**
     * 子目名称
     */
    public void setSonItemName(java.lang.String sonItemName) {
        this.sonItemName = sonItemName;
    }
    /**
     * 子目特征描述
     */
    public java.lang.String getSonItemDescribe() {
        return sonItemDescribe;
    }

    /**
     * 子目特征描述
     */
    public void setSonItemDescribe(java.lang.String sonItemDescribe) {
        this.sonItemDescribe = sonItemDescribe;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getEngineering() {
        return engineering;
    }

    /**
     * 工程量
     */
    public void setEngineering(java.math.BigDecimal engineering) {
        this.engineering = engineering;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLabor() {
        return labor;
    }

    /**
     * 人工费
     */
    public void setLabor(java.math.BigDecimal labor) {
        this.labor = labor;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterial() {
        return material;
    }

    /**
     * 材料费
     */
    public void setMaterial(java.math.BigDecimal material) {
        this.material = material;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanical() {
        return mechanical;
    }

    /**
     * 机械费
     */
    public void setMechanical(java.math.BigDecimal mechanical) {
        this.mechanical = mechanical;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getManagement() {
        return management;
    }

    /**
     * 企业管理费
     */
    public void setManagement(java.math.BigDecimal management) {
        this.management = management;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfit() {
        return profit;
    }

    /**
     * 利润
     */
    public void setProfit(java.math.BigDecimal profit) {
        this.profit = profit;
    }
    /**
     * 综合单价
     */
    public java.math.BigDecimal getUnitPrice() {
        return unitPrice;
    }

    /**
     * 综合单价
     */
    public void setUnitPrice(java.math.BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getShutLabor() {
        return shutLabor;
    }

    /**
     * 人工费
     */
    public void setShutLabor(java.math.BigDecimal shutLabor) {
        this.shutLabor = shutLabor;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getShutMaterial() {
        return shutMaterial;
    }

    /**
     * 材料费
     */
    public void setShutMaterial(java.math.BigDecimal shutMaterial) {
        this.shutMaterial = shutMaterial;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getShutMechanical() {
        return shutMechanical;
    }

    /**
     * 机械费
     */
    public void setShutMechanical(java.math.BigDecimal shutMechanical) {
        this.shutMechanical = shutMechanical;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getShutManagement() {
        return shutManagement;
    }

    /**
     * 企业管理费
     */
    public void setShutManagement(java.math.BigDecimal shutManagement) {
        this.shutManagement = shutManagement;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getShutProfit() {
        return shutProfit;
    }

    /**
     * 利润
     */
    public void setShutProfit(java.math.BigDecimal shutProfit) {
        this.shutProfit = shutProfit;
    }
    /**
     * 合价(元)
     */
    public java.math.BigDecimal getShutPrice() {
        return shutPrice;
    }

    /**
     * 合价(元)
     */
    public void setShutPrice(java.math.BigDecimal shutPrice) {
        this.shutPrice = shutPrice;
    }
    /**
     * 社保
     */
    public java.math.BigDecimal getClubInsurance() {
        return clubInsurance;
    }

    /**
     * 社保
     */
    public void setClubInsurance(java.math.BigDecimal clubInsurance) {
        this.clubInsurance = clubInsurance;
    }
    /**
     * 住房
     */
    public java.math.BigDecimal getHousing() {
        return housing;
    }

    /**
     * 住房
     */
    public void setHousing(java.math.BigDecimal housing) {
        this.housing = housing;
    }
    /**
     * 预留1
     */
    public java.math.BigDecimal getReserved1() {
        return reserved1;
    }

    /**
     * 预留1
     */
    public void setReserved1(java.math.BigDecimal reserved1) {
        this.reserved1 = reserved1;
    }
    /**
     * 预留2
     */
    public java.math.BigDecimal getReserved2() {
        return reserved2;
    }

    /**
     * 预留2
     */
    public void setReserved2(java.math.BigDecimal reserved2) {
        this.reserved2 = reserved2;
    }
    /**
     * 预留3
     */
    public java.math.BigDecimal getReserved3() {
        return reserved3;
    }

    /**
     * 预留3
     */
    public void setReserved3(java.math.BigDecimal reserved3) {
        this.reserved3 = reserved3;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 暂估价(元)
     */
    public java.math.BigDecimal getEstimation() {
        return estimation;
    }

    /**
     * 暂估价(元)
     */
    public void setEstimation(java.math.BigDecimal estimation) {
        this.estimation = estimation;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
}
